package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.36.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.36.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````>10``#0```!0`0$```0`!30`(``'
M`"@`%@`5``8````T````-````#0```#@````X`````0````$`````P```!0!
M```4`0``%`$``!@````8````!`````$````!````````````````````''(`
M`!QR```%```````!``$```#,_0``S/T!`,S]`0!P`@``G`(```8```````$`
M`@```-3]``#4_0$`U/T!`/````#P````!@````0```!1Y71D````````````
M```````````````&````$````%+E=&3,_0``S/T!`,S]`0`T`@``-`(```0`
M```!````+VQI8B]L9"UM=7-L+6%R;6AF+G-O+C$`$0```$P````(````"```
M``&0$``E0`2`*(`0!:"&4(2``0``"R`$C3B`$D&*!`@(3````$T```!1````
M5@```%<```!>````7P```&``````````8@```&,`````````9````&4```!H
M```````````````!KS3H:G^:?.K3[P[.WD<M;\7?'R[%F[:XC?$.U&34?'94
M/)0A_^0.V7%8'/JA;&#"Y3\LL@&+;T+ZUX?B1\8!6.^7>;OCDGQ5PSS29Z_,
M9H@'<--#1=7L,V+;[16,)<Q_J9R;X*<""FH:GE"_VE<;H^#[20``````````
M````````````````!!`````````#``<``````````@```````P`1``$`````
M`````````!(````)```````````````1````\P$`````````````$0```'P!
M`````````````!(````0```````````````2````S`$`````````````$@``
M`!@``````````````!(````?```````````````2``````(`````````````
M$@```-@!`````````````!(````H```````````````@````&@,`````````
M````(0```$```````````````!(```!&```````````````2````30``````
M````````$@```-$"`````````````!(```#O`@`````````````2````5```
M````````````$@```#("`````````````!(```!;```````````````2````
MN`(`````````````$@```&(``````````````!(```!J```````````````2
M````R@(`````````````$@```'(``````````````!(```"A`@``````````
M```2````>@``````````````$@```(,``````````````"````#A`@``````
M```````2````GP``````````````$@```*0``````````````!(```"9`0``
M```````````6````OP(`````````````$@```%\"`````````````!(```"K
M```````````````2````40(`````````````$@```%X#`````````````!(`
M```9`P`````````````1````@P(`````````````$@````8#````````````
M`!(````1`@`````````````2````&P,`````````````$0```+(`````````
M`````!(```"[```````````````1````B@$`````````````$@```,T`````
M`````````"(```#<```````````````@````\@``````````````$@```/X"
M`````````````!(```!O`@`````````````2````]P``````````````$@``
M`/T``````````````"````"L`@`````````````2````%P$`````````````
M$@```+T!`````````````!(````<`0`````````````2````D0(`````````
M````$@```"(!`````````````!(```"L`0`````````````2````,`$`````
M````````$@```$$!`````````````!(````M`@`````````````2````/@(`
M````````````$@```$<!`````````````!(```!X`@`````````````2````
MZ`(`````````````$@```-D"`````````````!(```!6`0`````````````2
M````*`(`````````````$@```%T!`````````````!(```!D`0``````````
M```2````&`,`````````````(0```'4!`````````````!(```!>!```:``"
M```````0`!(`$P,``/T2``!\`0``$@`)`.T!``!%,````@```!(`"@"@`P``
M)1\``,P$```2``D`;@0``*$E```X````$@`)`'T#``#1&@``!````!(`"0`2
M!```!1````(````2``<`PP,``/$C``"P`0``$@`)`!@$```\``(``````!``
M$@!&!```U1H``'`!```2``D`^P,``#P``@``````$``2`(X#``"Y'@``;```
M`!(`"0"M`P``=1D``$`````2``D`M0,``&D>``!`````$@`)`-D#``#)+@``
MP@```!(`"0#N`P``11P``!@````2``D`!P0``&@``@``````$``2`&D$``!H
M``(``````!``$@!#`P``E10``$`````2``D`)@0``%T<```$`0``$@`)`.0#
M```X``(`!````!$`$0`_!```/``"```````0`!$```0``'D4````````$@`)
M``\$``"-+@``/````!(`"0!,`P``J1X``!`````2``D`9P,``/T9``#4````
M$@`)`%,$``"++P``N````!(`"0!=!```:``"```````0`!(`,@0``&$=```(
M`0``$@`)``!O<&5N9&ER`'-T9&5R<@!R96%L;&]C`&%C8V5S<P!S;G!R:6YT
M9@!?7V1E<F5G:7-T97)?9G)A;65?:6YF;P!L<V5E:P!G971P:60`<W1R8VUP
M`&UE;7-E=`!U;FQI;FL`;65M;6]V90!S=')N8VUP`'-T<G)C:'(`8VQO<V5D
M:7(`7TE435]D97)E9VES=&5R5$U#;&]N951A8FQE`&]P96X`<W1R<W1R`'-T
M<F-H<@!R96%D;&EN:P!?7W-T86-K7V-H:U]G=6%R9`!?7V-X85]F:6YA;&EZ
M90!?7W)E9VES=&5R7V9R86UE7VEN9F\`97AI=`!C;&]S90!?251-7W)E9VES
M=&5R5$U#;&]N951A8FQE`')E860`<FUD:7(`7U]S=&%T7W1I;64V-`!?7V5R
M<FYO7VQO8V%T:6]N`&UK9&ER`%]?;'-T871?=&EM938T`&UE;6-P>0!S=')L
M96X`7U]S=&%C:U]C:&M?9F%I;`!G971U:60`4&5R;%]S>7-?=&5R;0!097)L
M7W-Y<U]I;FET,P!03%]C=7)R96YT7V-O;G1E>'0`4&5R;%]A=&9O<FM?;&]C
M:P!P97)L7V-O;G-T<G5C=`!097)L7V=E=%]S=@!097)L7V-R;V%K7VYO8V]N
M=&5X=`!?9FEN:0!03%]D;U]U;F1U;7``4&5R;%]N97=84U]F;&%G<P!097)L
M7V-R;V%K7VUE;6]R>5]W<F%P`'!E<FQ?9G)E90!097)L7VUG7W-E=`!097)L
M7V%T9F]R:U]U;FQO8VL`4&5R;%]S=E]S971P=@!097)L7V=V7V9E=&-H<'8`
M<&5R;%]R=6X`4&5R;%]N97=84P!P97)L7V1E<W1R=6-T`&)O;W1?1'EN84QO
M861E<@!P97)L7W!A<G-E`%!E<FQ?<V%F97-Y<VUA;&QO8P!P97)L7V%L;&]C
M`'-T<F-P>0!R96%D9&ER`'-P<FEN=&8`<W1R9'5P`'-T<G1O:P!P=&AR96%D
M7V%T9F]R:P!F<')I;G1F`%]?;&EB8U]S=&%R=%]M86EN`%]?7V5N=FER;VX`
M;&EB<&5R;"YS;P!L:6)C+FUU<VPM87)M=C<N<V\N,0!?<W1A<G1?8P!G971?
M=7-E<FYA;65?9G)O;5]G971P=W5I9`!P87)?8W5R<F5N=%]E>&5C7W!R;V,`
M<&%R7V-U<G)E;G1?97AE8P!P87)?<V5T=7!?;&EB<&%T:`!P87)?;6MT;7!D
M:7(`>'-?:6YI=`!P87)?96YV7V-L96%N`%A37TEN=&5R;F%L<U]005)?0D]/
M5`!S:&%?=7!D871E`&UY7W!A<E]P;`!P87)?8F%S96YA;64`7U]B<W-?<W1A
M<G0`7U]E;F1?7P!S:&%?:6YI=`!?7V)S<U]S=&%R=%]?`'!A<E]D:7)N86UE
M`'!A<E]I;FET7V5N=@!?961A=&$`<&%R7V9I;F1P<F]G`'-H85]F:6YA;`!?
M7V)S<U]E;F1?7P!?96YD`'!A<E]C;&5A;G5P`"]U<W(O;&EB+W!E<FPU+V-O
M<F5?<&5R;"]#3U)%`,S]`0`7````T/T!`!<```#`_P$`%P```,S_`0`7````
MV/\!`!<```````(`%P````@``@`7````#``"`!<````4``(`%P```!@``@`7
M````'``"`!<````@``(`%P```"0``@`7````+``"`!<````P``(`%P```#@`
M`@`7````Q/\!`!4$``#(_P$`%04``-#_`0`5#0``U/\!`!4>``#<_P$`$R(`
M`.#_`0`5+```Y/\!`!4N``#H_P$`%3```.S_`0`5,0``\/\!`!4V``#T_P$`
M%3L``/C_`0`5/0``_/\!`!5!``#0_@$`%@,``-3^`0`6!@``V/X!`!8'``#<
M_@$`%@@``.#^`0`6"0``Y/X!`!8*``#H_@$`%@L``.S^`0`6#```\/X!`!8-
M``#T_@$`%@\``/C^`0`6$```_/X!`!81````_P$`%A(```3_`0`6$P``"/\!
M`!84```,_P$`%A4``!#_`0`6%@``%/\!`!87```8_P$`%A@``!S_`0`6&0``
M(/\!`!8:```D_P$`%AL``"C_`0`6'```+/\!`!8=```P_P$`%A\``#3_`0`6
M(```./\!`!8A```\_P$`%B,``$#_`0`6)```1/\!`!8E``!(_P$`%B8``$S_
M`0`6)P``4/\!`!8I``!4_P$`%BH``%C_`0`6*P``7/\!`!8M``!@_P$`%B\`
M`&3_`0`6,```:/\!`!8Q``!L_P$`%C(``'#_`0`6,P``=/\!`!8T``!X_P$`
M%C4``'S_`0`6-P``@/\!`!8X``"$_P$`%CD``(C_`0`6.@``C/\!`!8\``"0
M_P$`%CX``)3_`0`6/P``F/\!`!9```"<_P$`%D(``*#_`0`60P``I/\!`!9$
M``"H_P$`%D4``*S_`0`61@``L/\!`!9'``"T_P$`%D@``+C_`0`620``O/\!
M`!9+```!M;WH`4!P1P3@+>4$X)_E#N"/X`CPON6H[@$``,:/XA[*C.*H_KSE
M`,:/XA[*C.*@_KSE`,:/XA[*C.*8_KSE`,:/XA[*C.*0_KSE`,:/XA[*C.*(
M_KSE`,:/XA[*C.*`_KSE`,:/XA[*C.)X_KSE`,:/XA[*C.)P_KSE`,:/XA[*
MC.)H_KSE`,:/XA[*C.)@_KSE`,:/XA[*C.)8_KSE`,:/XA[*C.)0_KSE`,:/
MXA[*C.)(_KSE`,:/XA[*C.)`_KSE`,:/XA[*C.(X_KSE`,:/XA[*C.(P_KSE
M`,:/XA[*C.(H_KSE`,:/XA[*C.(@_KSE`,:/XA[*C.(8_KSE`,:/XA[*C.(0
M_KSE`,:/XA[*C.((_KSE`,:/XA[*C.(`_KSE`,:/XA[*C.+X_;SE`,:/XA[*
MC.+P_;SE>$?]YP#&C^(>RHSBY/V\Y0#&C^(>RHSBW/V\Y0#&C^(>RHSBU/V\
MY0#&C^(>RHSBS/V\Y0#&C^(>RHSBQ/V\Y0#&C^(>RHSBO/V\Y0#&C^(>RHSB
MM/V\Y0#&C^(>RHSBK/V\Y0#&C^(>RHSBI/V\Y0#&C^(>RHSBG/V\Y0#&C^(>
MRHSBE/V\Y0#&C^(>RHSBC/V\Y0#&C^(>RHSBA/V\Y0#&C^(>RHSB?/V\Y0#&
MC^(>RHSB=/V\Y0#&C^(>RHSB;/V\Y0#&C^(>RHSB9/V\Y0#&C^(>RHSB7/V\
MY0#&C^(>RHSB5/V\Y0#&C^(>RHSB3/V\Y0#&C^(>RHSB1/V\Y0#&C^(>RHSB
M//V\Y0#&C^(>RHSB-/V\Y0#&C^(>RHSB+/V\Y0#&C^(>RHSB)/V\Y0#&C^(>
MRHSB'/V\Y7A'_><`QH_B'LJ,XA#]O.4`QH_B'LJ,X@C]O.5X1_WG`,:/XA[*
MC.+\_+SE`,:/XA[*C.+T_+SE`,:/XA[*C.+L_+SE`,:/XA[*C.+D_+SE`,:/
MXA[*C.+<_+SE`,:/XA[*C.+4_+SE`,:/XA[*C.+,_+SE`,:/XA[*C.+$_+SE
M<+6(L,WI!A`%D@:I!:H'J$I,__=B[TI+?$3C6`.324L#FN-8$4881@23__?*
M[D9+XU@=[G!/'7B%N?_W&.]#2GI$T&`0N0$@__=8[__W>N\X2WM$&VCC6(/X
M>U<V2P>8>T0;:.)8Q1R2^,XS!#!#\`,#L/&`3X+XSC,!T__W(.^``/_W5.\R
M2@-&>D108`::!YP1:`%@+TEY1$%@+DEY1`EH@6`M27E$0/@,'P$AC$(YW``L
M!/$#`4_P``)/ZH$!V+\0(29.6E`F20"2?D0J1O!H>43_]ZKN!$88N?!H__<:
M[P1&($U]1.AH__?>[A](>$0`\!OY8+FK:".Y'$AX1`#P%/FH8!M+>T28:`BQ
M`?#)^!E+>T38:/_W6N__]PCN($8(L'"]4O@A8`$Q0/@$;[WG`+^*[`$`?.P!
M`*SK`0`X`0``-`$```0!```8[0$`SNP!`,H?``":[`$`OQ\``(SL`0#C!0``
M<NP!`($=```H'0``4.P!`$3L`0!/\``+3_``#@-)>41H1B#P#PSE1@#P`OA.
MZ0$`'[4+2PM*>T2:6`*2"DJ:6`.2`"(!D@E*FU@"'0"3`6@"FP.8__=Z[@6P
M7?@$^P"_)NH!`!0!``#\````"`$```9(!TL'2GA$>T2#0GI$`]`%2]-8`[$8
M1W!'`+]>ZP$`7.L!`.#I`0`0`0``"$@)2WA$>T0;&MD/!TH!ZZ,!21!Z1`/0
M!4O36`.Q&$=P1P"_-.L!`#+K`0"LZ0$`+`$```Y+$+5[1`Y,&WA\1*.Y#4OC
M6".Q#$M[1!AH__=([O_WO_\*2^-8&[$)2'A$__>.[0$B"$M[1!IP$+T`OP#K
M`0""Z0$`)`$``++J`0`,`0``MEP``-#J`0`(M0=+!TI[1)M8*[$&20=(>41X
M1/_W).Z]Z`A`JN<`OR[I`0`H`0``H.H!`'9<```82RWI\$=[1(I&!49`LQ9*
MFU@<:`RS`T8>1A/X`2LZN:%&=AO(1EGX!'LGN3Q&%.`]*O70\.<R1BE&.$;_
M]X3M`"COT;M=/2OLT:CK!`A/ZJ@#`3;*^``PO!D@1KWH\(<$1OKG_N@!`!P!
M```'M0U*#4MZ1--8:48;:`&33_```__WOO\)2@A+>D336!IH`9M:0$_P``,!
MT/_W1NX#L%WX!/L`OY+H`0`@`0``?.@!`'.U%4H52WI$TU@$1AMH`9-/\``#
M;D8237U$,48@1O_WE_]8N0]*#4MZ1--8&F@!FUI`3_```PW0__<>[@I+`)KK
M6!MH`^N"`UIH0_@$*P`J^M'BYP*P<+U.Z`$`(`$``#SH`0`LZ`$`'`$``!"U
M%TH72WI$J+#36&E&!$8;:">33_```__WS.W8N02;`_1P0[/U@$\"T+/U($\&
MT0(A($;_]Z#LL/J`\$`)"DH(2WI$TU@::">;6D!/\``#`]#_]]SM`"#QYRBP
M$+T`O^+G`0`@`0``IN<!`"WI\$,R2C-+>D336*FP&V@GDT_P``,%1K"Q`WBC
ML?_W7NP'1H"QW_BP@-_XL)#X1/E$.$;_]YKL!$:(N3A&__?8["A&__=@[25*
M(DMZ1--8&F@GFUI`3_```S;0__>@[1,T048@1O_W?.P`*.'0248@1O_W=NP`
M*-O0*$;_]XKM!D8@1O_WANTP1`(P__>,[`9&%$DC1BI&>43_]VKM:48P1O_W
M..T!,#!&"]`$FP/T<$.S]8!/!='_]Z+_,$;_]S[MMN?_]VKL^.<IL+WH\(-T
MYP$`(`$``&<9``!D&0``,.<!`/\8```MZ?!/#49*2DI+>D336(6P&V@#DT_P
M``,+>`9&/2L(OP$U*$;_]T+M`JD'1C!&__>O_M_X!)$$1OE$L+'_]S;MAT(S
MV`$\%?@!.P3X`3\`*_G1.DHW2WI$TU@::`.;6D!/\``#8-#_]RCM-4M9^`.@
MVO@`L%OX)#``*T+1,4L$\0((>T0::$_JB`@`*CO004981O_WO.O*^````"C9
MT``BVO@`,`*40T1#^`0L,T881A/X`2L*L3TJ^=$A2X`;6?@#0`(W.$3=^`B`
MU/@`D/_W^.M)^"@``"B[T"-H4_@H(!;X`1L31A%P`3()L3TI]]$](AIP%?@!
M*P/X`2\`*OG1I^<!-+;G`2)`1AI@__?8ZP&0`"B=T%E&J/$(`O_WUNL!F\KX
M`#"ZYP6PO>CPCP"_BN8!`"`!``!<Y@$`/N8!`!P!``"FYP$`%[0+2PM*>T2;
M6`A(`9-X1`!H'>YP3PA+"$D!FB!8>T1Y1`.P7?@$2__W?+Q6Y@$`1N4!`#`!
M``#F5P``31<``!.U#$L=[G!/>T0;:.!8__?7_P`B"$@)2WA$`&A[1,WI`#('
M20=*(%AZ1'E$__="ZP*P$+T<Y@$`#.8!`(T9```?%P``$0H``#"U+THO2ZWU
M`%V'L'I$TU@-]0!1%#$;:`M@3_```__W/NLI2@.L>D0`DBA*`T9!\@$!($9Z
M1/_W%.M#'`_1`",C22!*>40-]0!0BE@4,!%H`FA10$_P``(MT/_W1NRP]8!?
M`-G_W@WU@%40-2!&3_2`4BE&__>JZP0>X-M@'/_W..L#1@`HVM"H0@+2`AF5
M0NC3JT("V2H9DT+CTT'R`0*40M_<(D881BE&__<,[``B`T8"5<3G&$8-]0!=
M![`PO;CD`0`@`0``_!8``.(6``"`Y`$`__>4ORWI\$]/2JWUA5U/2X.P>D0%
M1DY(TU@,1@WUA5%X1`0Q&V@+8$_P``/_]Y3]+R$&1BA&__<\ZYBQ14@I1GA$
M__>+_D1*0$MZ1`WUA5'36`0Q&F@+:%I`3_```VW0__?8ZR!&__<&ZSQ)/$]Y
M1/_WLNL$1M_X[(#?^.R0?T3X1/E$`"S9T"-X`"L(OSQ&+K$A1C!&__>>Z@`H
M1]`@1O_WLNL`(4,>(T2<0@+2&G@O*A[0($;_]ZCK@D8H1O_WI.N"1`KQ`0JZ
M]8!?MM(-\:@+J_$$"B-&0D9/](!14$;-Z0"5__=2Z@$PL/6`7P/9_]X#^`$9
MV.=01@*I__=$ZZBY6_B0/`/T<$.S]0!/#M$!(5!&__<TZDBY%$A11GA$__<<
M_E!&__>FZ@5&B^<020`@>43_]U#K!$:CYRA&#?6%70.PO>CPC][C`0`@`0``
M,A8``!L6``"FXP$`^A4``(L5``"V%@``Z!4``#T5```V%0``$+4O(01&__=H
MZ@"Q1!P@1KWH$$#_]W*Z,+4Y2CE+K?6`77I$@[`-]8!1TU@$,05&&V@+8$_P
M``,(L0-XN[DR2C!+>D0-]8!1TU@$,1IH"VA:0$_P``,!T/_W(NLK2'A$#?6`
M70.PO>@P0/_W1[K_]Q+K`3"P]8!?/]@!K"E&($;_]R3J($;_]P;K`"(!."!$
MH$("V0-X+RL4T"\A($;_]QSJD+D:2A=+>D0-]8!1TU@$,1IH"VA:0$_P``/,
MT15(>$3-YP#X`2GBYZ!"A+\`(P-P($;_]Q3J#TH*2WI$#?6`4=-8!#$::`MH
M6D!/\``#LM$-]8!=`[`PO0`@[.<`OUKB`0`@`0``.N(!`#<4``#4X0$`U1,`
M`*#A`0`M2!"U>$3_]X'\+$@L3'A$__=\_"M(?$1X1/_W=_PJ2'A$__=S_"E(
M>$3_]V_\*$AX1/_W:_PG2'A$__=G_"9(>$3_]V/\($;_]V#\(TAX1/_W7/PB
M2'A$__=8_"%(>$3_]S+\`480L2!&__<O_1Y(>$3_]RG\`488L1Q(>$3_]R7]
M&TAX1/_W'_P!1E"Q&4AX1/_W&_V]Z!!`%TD72'E$>$03Y19(>$3_]P[\`48`
M*/'0%$AX1.SGV!,``-<3```-%```U1,``-83``#5$P``W1,``(H3``#9$P``
MWQ,``'43``#9$P``V!,``-X3``#A$P``,A,``.@3``!=$P``SQ,``&43```(
MM0M+>T0;:`$S#-$)2'A$__?6^R"Q`'@0L3`X&+\!(`5+>T088`5+>T08:`B]
M`+^4X0$``Q,``';A`0!PX0$`"+7_]R+J__=TZ0"Q`&@(O?>U%D\$1G]$.$;_
M]['[(48%1@BQ`W@KN1%(>$0#L+WH\$"GY/_W/NFPN2!&__?XZ09&*$;_]_3I
M,$0",/_W^N@&1@A+"$DB1GE$`)5[1/_WUNDQ1CA&X><#L/"]*A,``!83```T
M$@``!A,``"WI\$_?^#PDW_@\-*WU`4V)L'I$W_@T5--8#?4!04BL?40;:,MA
M3_```RH=I/%T`P7Q$`ZD\5P,'#$&1@?*@^@'`+[H#P"LZ`\`GN@#`*3Q:`,H
M-8SH`P"5Z`<`@^@'`/M(_$]X1/_W3?M_1`5&T+$#>,.Q__>.__=*\TMZ1`WU
M`4'36!PQ&F@+:%I`3_```P'0__>6Z2A&#?4!30FPO>CP3__WN[C_]VW_!4:8
MN:3Q:`A8^`0+$+GH37U$"^#_]R'[`"CUT`-X`"ORT/_WJ.@%1@`H[=`H1O_W
M;.E```$P__=RZ(%&@$;?^'2C`3WZ1!7X`2\`*F;1I/%<"%CX!%N%L2A&__?^
M^@5&`"CVT`-X`"OST/_W3OL`*._0*$;_]X#H!4:D\70*1;E:^`2+N/$`#UG0
MF/@`,``K2]$H1O_W.NF"1DA&__<VZ8)$"O($2E!&__<ZZ(!&PDO#27M$`)/"
M2RI&>T1Y1,WX!)#_]Q#I3_3@<4!&__?JZ`$P-M'_]^#H`V@1*S'0N4JZ2;A8
M`),R:$-&`&AY1/_WHN@`);9*J4MZ1`WU`4'36!PQ&F@+:%I`3_```W_T;*\H
M1@WU`4T)L+WH\(]`1E%&__?BZ`CQ`@B-YT!&__?M^@`HI=!`1O_W'N@%1I_G
M14:GYT!&!*G_][KH@48XN:3UB'4K:0/T<$.S]8!/"="92YQ)^%@R:$-&>40`
M:/_W9.B_Y]7X&+#_]]3H@T7OT2MIP_,(`[/UX'_IT5!&_O?([P5&D$AX1/_W
M8/H!1@`H?]$W:#A&__>RZ`,H@D8>V8I)!#AY1#A$_O>.[[BYNO$$#P30ND0:
M^`4\+RL/T79H;K$P1O_WFN@#*`C9@$D$.'E$,$3^]WCO`"@(OS=&__=5_H)&
M`"A`\)R``48X1O[WPN\&1@`H`/"4@$_P`@E/\/\S;_`1`LWX`)`G'_[W4.\&
M(CE&,$;_]R#H%/@$/``K/]$4^`,\0RL[T13X`CQ!*S?1%/@!/$,K,]$C>$@K
M,-%C>$4K+=%/\/\S;_`Y`C!&S?@`D/[W+.\I(CE&,$;^]_SO0D9;2UQ)>T3-
MZ0!S6TMY1'M$*$;_]S#H0$;_]Q+H5T@I1GA$__?C^BA&__<F_BGG,&C_]S#\
M!T8`*'_T>J]WYP`C`"(`DS!&`"/^]P#O`/#^_8%&3_0`0CE&,$;^]\SO`AXH
MW#!&I/%$!O[WN.^D\3`'248P1@#P:?ZY1M_X!+'[1#A&6486^`$K"O$!"O[W
M\N^Z\10/!_$"!_+1`",$^`@\.$LY27M$S>D`DSA+0D9[1'E$K><Y1DA&`/#F
M_<GG-$DT2'E$>$3_]Y'Z_O?&[C)+,DE[1,WI``,Q2T)&*$9[1'E$_O?([R],
M+TXP3WQ$?D1_1$_TX'$H1O[WFN\!,(K1_O>0[P-H$2N%T?[WINX)\0$)`)`C
M1D)&,48H1LWI`9?^]ZCOY><`OXK?`0`@`0``O.`!`)H1```RWP$`(-\!`!H2
M``#M$0``C1$``'H1``"R$`````$``%@1``#ZW0$`%Q$``)$0```@$0``^1``
M`!D1``!>$```[`X``,(.``!!#P``>1```+H/``!,#@``Y`X``'4.``!+$```
MF0\``!P.```.#@``F0\``"T0``!PM51+'>YP3WM$&VCC6%M(D_AD('A$@_AE
M(/_W#?D@L0-X,2L!T4-X"['_]Z'\2DA327A$`&@#(P$B(%AY1/[WHNX%1J"Q
M14O!:'M$&VA-2@EHX%AZ1/[WHN[K:!EHBVA;`@75/DM[1!MHX%C^]SKN/$A%
M27A$`&@#(P$B(%AY1/[W@.X&1OBQ0$AX1/_WU/@"1D"Q-$OQ:'M$&V@):.!8
M_O=\[A#@__>Q^O%H!48`*#+0+DL"1GM$&V@):.!8_O=N[BA&_O?D[BE+,4E[
M1!MHY5@!(GE$*$;^][SM+4H!1GI$*$;^]UKN(DL`(GM$&V@I2.-8>$2#^&4@
M__>=^"=,?$2@8("Y8&C_]Q3]H&!8N2-(>$3^][;M(DM[1%IH%DL2:'M$&VBY
MYQ],3_3@<7Q$H&C^]Z;N0AP!*@-&"-D1*`;0U.D!$AE("6AX1/[WFNUPO0"_
MX-L!`+;;`0">VP$`@ML!`'3;`0!0VP$`,ML!`!S;`0#\V@$`QMH!`%D-``"L
M#@``E@X``'$.``"Q#```'0X``"8.```^#```9-L!`/H-``!*VP$`-ML!`.,-
M```XM01&__=:^__W3/L%1O_W6_QPL6RQ(WA;L09)*$9Y1/[WS.V%0@31($:]
MZ#A`__>YN#B]3PP``"WI\$_]2OY+>D33L--8`:H41AMH49-/\``#`/%<!0#Q
M'`-3^`0;";J=0D3X!!OXT1`D$48-:DMK`31K0(UH"6AK0$M`!#)/ZO-S4"S3
M8_#1Z$_0Z0#F`9D":3E$T/@(P!%$PFC$:(SJ`@(R0&)``>O^81%$`IJ,ZK8%
M.D0%Z@X%(D2%Z@P%3^J^!!5$`YJ$ZK8*"NH!"CI$BNJV"F)$DD0$F@7K\66$
MZK$)">H%"3I$`NNV`HGJ!`D*Z_5JD41/ZK4%!9J%ZK$(".H*"#I$(D2(ZK$(
MD$0&F@GK^FF%ZKH$!.H)!#I$`NNQ`FQ`".OY:!1$3^JY"0>:B>JZ`0'J"`$Z
M1"I$@>JZ`1%$")H$Z_ADB>JX!25`.D0"Z[H"A>H)!0'K]&$51$_JM`0)FH3J
MN`H*Z@$*.D1*1(KJN`J21`J:!>OQ983JL0D)Z@4).D0"Z[@"B>H$"0KK]6J1
M1$_JM04+FH7JL0@(Z@H(.D0B1(CJL0B01`R:">OZ:87JN@0$Z@D$.D0"Z[$"
M;$`(Z_EH%$1/ZKD)#9J)ZKH!`>H(`3I$*D2!ZKH!$40.F@3K^&2)ZK@%)4`Z
M1`+KN@*%Z@D%`>OT815$3^JT!`^:A.JX"POJ`0LZ1$I$B^JX"Y-$$)H%Z_%E
MA.JQ"0GJ!0DZ1`+KN`*)Z@0)"^OU:Y%$3^JU!1&:A>JQ"@KJ"PHZ1")$BNJQ
M"I)$$IH)Z_MIA>J[!#I$"NOY:@+KL0($Z@D$$YE/ZKD)B>J["&Q`%$0(Z@H(
M%)HY1`3K^F0I1(CJNPB)ZKH%B$0E0&E).D05GPCK]&@"Z[L"3^JT!(7J"045
M1`]$A.JZ`H+J"`)/1!=$%IH%Z_AE`NL!"83JN`)J0`GKN@F11!>:!^OU9T_J
MM04"ZP$*A>JX`GI`HD221!B:">OW:508A>JW`H+J"0($Z[@$%$09F@KK^6I/
MZKD)`NL!"(GJMP*"Z@H"J$201!J:!.OZ9%48!>NW!8GJN@(;GPCK]&AB0$_J
MM`051`]$A.JZ`H+J"`)/1!=$')H%Z_AE`NL!"83JN`)J0`GKN@F11!V:!^OU
M9T_JM04"ZP$*A>JX`GI`HD221!Z:">OW:508A>JW`H+J"0($Z[@$%$0?F@KK
M^6I/ZKD)`NL!"(GJMP*"Z@H"J$201"":!.OZ9%48!>NW!8GJN@(AGPCK]&AB
M0$_JM`051`]$A.JZ`H+J"`)/1!=$(IH%Z_AE`NL!"83JN`)J0`GKN@F11".:
M!^OU9T_JM04"ZP$*A>JX`GI`HD221"2:">OW:508A>JW`H+J"0($Z[@$%$0E
MF@KK^6I/ZKD)`NL!"(GJMP*"Z@H"J$201"::!.OZ9%48!^"9>8):H>O9;N#8
M`0`@`0``!>NW!8GJN@(GGPCK]&AB0$_JM`051`]$A.JZ`H+J"`)/1!=$*)H%
MZ_AE`NL!"83JN`('Z_5G:D!/ZK4%">NZ"47JN`J11`KJ!PH%ZK@"*9E*Z@(*
MZTH)Z_=I$40A1$7JMP2*1`3J"00%ZK<!#$,JF0KK^6H11$_JN0D!Z[@!2>JW
M"`Q$".H*"`GJMP%(Z@$(*YD$Z_ID$40I1$GJN@6(1"5`">JZ`0U#+)D(Z_1H
M$41/ZK0$`>NW`43JN@<-1`?J"`<$ZKH!#T,MF07K^&411$E$1.JX"0]$">H%
M"03JN`%)Z@$)+ID'Z_5G$41/ZK4%`>NZ`47JN`J)1`KJ!PH%ZK@!2NH!"B^9
M">OW:1%$(41%ZK<$BD0$Z@D$!>JW`0Q#,)D*Z_EJ$41/ZKD)`>NX`4GJMP@,
M1`CJ"@@)ZK<!2.H!"#&9!.OZ9!%$*41)ZKH%B$0E0`GJN@$-0S*9".OT:!%$
M3^JT!`'KMP%$ZKH'#40'Z@@'!.JZ`0]#,YD%Z_AE$41)1$3JN`D/1`GJ!0D$
MZK@!2>H!"329!^OU9Q%$3^JU!0'KN@%%ZK@*B40*Z@<*!>JX`4KJ`0HUF0GK
M]VD11"%$1>JW!(I$!.H)!`7JMP$,0S:9"NOY:A%$3^JY"0'KN`%)ZK<(#$0(
MZ@H(">JW`4CJ`0@WF03K^F011"E$B$1)ZKH!">JZ!2%`*4,XG0CK]&@51$_J
MM`0%Z[<%*41$ZKH%!.JZ!P7J"`4]0SF?`>OX81=$3T1$ZK@)/40)Z@$)!.JX
M!TGJ!PDZGP7K\6471$_JL0$'Z[H'0>JX"KE$"NH%"@'JN`=*Z@<*.Y\)Z_5I
M%T0G1$'JM00$Z@D$5T0!ZK4*1.H*"CR<!^OY9Q1$!.NX!`+Q;5(*ZP0(`O7@
M(CV<`O+Z0D_JN0D41`Q$B>JU`7E`#$0^F0CK]V@11`'KM0&)ZK<%A>H(!2E$
M/YT$Z_AD%41/ZK@(J42(ZK<%94"I1$"=`>OT815$!>NW!8CJM`=/0#U$09]/
MZK$*">OQ:1=$BNJT`8'J"0%'1`]$0ID%Z_EE$40!Z[0!BNJY!&Q`(41#G`?K
M]6=/ZK4%!.L""(7JN01\0-!$H$1$G`'K]V$41`3KN02%ZK<)B>H!"0CK\6A,
M1$_JL0E%F03K^&0!ZP(*B>JW`8'J"`&J1(I$1IF)ZK@%$41E0`'KMP$I1$>=
M3^JT"PKK]&H51(OJN`2$Z@H$340E1$B<`>OZ811$B^JZ!T]`!.NX!#Q$29]/
MZK$(!>OQ91=$B.JZ`6E`7T0/1$J9!.OU9(CJM0D11(GJ!`D!Z[H!!^OT9TE$
M3^JT"4N<`>OW811$H$2)ZK4$?$"@1$R<3^JQ"A1$!.NU!(GJMP5-0"Q$`>#<
MO!N/39T(Z_%H%41.F4U$BNJW"8GJ"`E-1`'K`@D$Z_AD">NW"8KJN`<!JV=`
MN433^#AQT_@\,07K]&5/ZK0$%T2$ZK@!$T0)Z_5IA.JU`FE`5T1S1(+J"0(/
M1`/KN`,'Z_EG$T0#Z_=C`V`,Z[D#@V##:`M*`^NU!0-I/D0<1`E+>D1&8,5@
M!&'36!IH49M:0$_P``,!T/[W-.I3L+WH\(\`OU[0`0`@`0``"+5@(/[W+.D*
M2@M)`F`"\8@R0F`"\2E"HO66$J+VBV*"8*+QB#+"8``BP.D$$H)APF4(O0$C
M16?PX=+#+>GP019&!49#:=(`FQ@HOX)I0V$DOP$R@F&#:0Q&`^M6<X-AP&T%
M\1P'`+/`\4`(L$4X1*B_L$:(0@32`.L(`YE"!=+_W@'K"`,!V9A"^.="1B%&
M_O?0Z>MM0T1`*^ME%-$H1J;K"`9$1/_W4?L%\5P(/RX,W+Q"']F[&9Q"X=,R
M1B%&.$;^][CI[F6]Z/"!O$($\4`##=E$1=/3.D94^`0;G$)"^`0;^=$H1D`^
M__<O^][G\M*?0N_GX=*C&9]"W><MZ?!!`?$<!TMICFD,1H`AD_J#^,/SQ0-:
M'#@J!48VNOE4!^L"`$/=`"'"\4`"_O>&Z"!&__<+^S@B`"$X1O[W?N@@1L3I
M%6C_]P'[XW@@1BMP8XAK<"-H&PJK<"-HZW#C>2MQXXAK<6-H&PJK<6-HZW'C
M>BMR8XEK<J-H&PJK<J-HZW+C>RMSXXEK<^-H&PJK<^-HZW/C?"MT8XIK="-I
M&PJK="-IZW2]Z/!!_O<AN0`APO$X`L+G`+\!M;WH`4!P1ST```!`````"P``
M`$`````0````0````"8```!`````-0```$`````#````0`````8```!`````
M%````$`````.````0`````T```!`````)0```$`````2````0````"@```!`
M`````@```$`````8````0`````D```!`````"@```$```````````````"XN
M`"5S+R5S`$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO861E<@!);G1E<FYA;',Z
M.E!!4CHZ0D]/5``O<')O8R\E:2\E<P!E>&4`4$%27U1%35``4$%27U!23T=.
M04U%`#H`+P!015),-4Q)0@!015),3$E"`%!%4DPU3U!4`%!%4DQ)3P!005)?
M24Y)5$E!3$E:140`4$%27U-005=.140`4$%27T-,14%.`%!!4E]$14)51P!0
M05)?0T%#2$4`4$%27T=,3T)!3%]$14)51P!005)?1TQ/0D%,7U1-4$1)4@!0
M05)?5$U01$E2`%!!4E]'3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.`#$`
M3$1?3$E"4D%265]0051(`%-94U1%30`E,#)X`"5S)7,E<R5S`'!A<BT`)7,Z
M(&-R96%T:6]N(&]F('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H
M97)R;F\])6DI"@`E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS
M869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO
M;BD*`'!A<FP`+G!A<@`E<R5S8V%C:&4M)7,E<P`E<R5S=&5M<"TE=25S`"5S
M)7-T96UP+25U+25U)7,`&`!P97)L`#``4$%2.CI086-K97(Z.E9%4E-)3TX`
M,2XP-38`56YA8FQE('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD`)7,Z(&-R
M96%T:6]N(&]F('!R:79A=&4@8V%C:&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE
M9"`H97)R;F\])6DI"@`M90`M+0!54T52`%5315).04U%`%1%35!$25(`5$U0
M`"]T;7``979A;"`G97AE8R`O=7-R+V)I;B]P97)L("`M4R`D,"`D>S$K(B1`
M(GTG"FEF(#`[(",@;F]T(')U;FYI;F<@=6YD97(@<V]M92!S:&5L;`IP86-K
M86=E(%]?<&%R7W!L.PIM>2`H)%!!4E]-04=)0RP@)$9)3$5?;V9F<V5T7W-I
M>F4L("1#04-(15]M87)K97(L("1C86-H95]N86UE7W-I>F4I.PI"14=)3B![
M"B1005)?34%'24,@/2`B7&Y005(N<&U<;B(["B1&24Q%7V]F9G-E=%]S:7IE
M(#T@-#L@("`C('!A8VLH(DXB*0HD8V%C:&5?;6%R:V5R(#T@(EPP0T%#2$4B
M.PHD8V%C:&5?;F%M95]S:7IE(#T@-#`["GT*<W5B(&9I;F1?<&%R7VUA9VEC
M"GL*;7D@*"1F:"D@/2!`7SL*;7D@)&-H=6YK7W-I>F4@/2`V-"`J(#$P,C0[
M"FUY("1B=68["FUY("1S:7IE(#T@+7,@)&9H.PIM>2`D<&]S(#T@)'-I>F4@
M+2`D<VEZ92`E("1C:'5N:U]S:7IE.R`@("`@(",@3D]413H@)'!O<R!I<R!A
M(&UU;'1I<&QE(&]F("1C:'5N:U]S:7IE"G=H:6QE("@D<&]S(#X](#`I('L*
M<V5E:R`D9F@L("1P;W,L(#`["G)E860@)&9H+"`D8G5F+"`D8VAU;FM?<VEZ
M92`K(&QE;F=T:"@D4$%27TU!1TE#*3L*:68@*"AM>2`D:2`](')I;F1E>"@D
M8G5F+"`D4$%27TU!1TE#*2D@/CT@,"D@>PHD<&]S("L]("1I.PIR971U<FX@
M)'!O<SL*?0HD<&]S("T]("1C:'5N:U]S:7IE.PI]"G)E='5R;B`M,3L*?0IM
M>2`H)'!A<E]T96UP+"`D<')O9VYA;64L($!T;7!F:6QE+"`E36]D=6QE0V%C
M:&4I.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]*2!["G)E<75I<F4@1FEL
M93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*<F5Q=6ER92!&:6QE
M.CI3<&5C.PIM>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H
M)'!A<E]T96UP*3L*;W5T<RAQ<5M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T
M96UP(ETI.PI&:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@
M<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*<FUD:7(@)'!A<E]T96UP
M.PII9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G35-7:6XS,B<I('L*;7D@
M)'1M<"`](&YE=R!&:6QE.CI496UP*`I414U03$%412`]/B`G=&UP6%A86%@G
M+`I$25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"E-5
M1D9)6"`]/B`G+F-M9"<L"E5.3$E.2R`]/B`P+`HI.PIM>2`D9FEL96YA;64@
M/2`D=&UP+3YF:6QE;F%M93L*<')I;G0@)'1M<"`\/"(N+BXB.PIX/3$[('=H
M:6QE(%L@7"1X("UL="`Q,"!=.R!D;PIR;2`M<F8@)R1P87)?=&5M<"<*:68@
M6R!<(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N"F)R96%K"F9I"G-L965P(#$*
M>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<D9FEL96YA;64G"BXN+@IC;&]S
M92`D=&UP.PIC:&UO9"`P-S`P+"`D9FEL96YA;64["FUY("1C;60@/2`B)&9I
M;&5N86UE(#XO9&5V+VYU;&P@,CXF,2`F(CL*<WES=&5M*"1C;60I.PIO=71S
M*'%Q6U-P87=N960@8F%C:V=R;W5N9"!P<F]C97-S('1O('!E<F9O<FT@8VQE
M86YU<#H@)&9I;&5N86UE72D["GT*?2!]"D)%1TE.('L*26YT97)N86QS.CI0
M05(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*
M979A;"!["E]P87)?:6YI=%]E;G8H*3L*;7D@)'%U:65T(#T@(21%3E9[4$%2
M7T1%0E5'?3L*;7D@)7-Y<R`]("@*<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O
M7DU35VEN+R`_("<[)R`Z("<Z)RDL"E]E>&4@("`@("`@(#T^("@D7D\@/7X@
M+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL"E]D96QI
M;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL
M"BD["E]S971?<')O9VYA;64H*3L*;W5T<RAQ<5M<)'!R;V=N86UE(#T@(B1P
M<F]G;F%M92)=*3L*7W-E=%]P87)?=&5M<"@I.PIO=71S*'%Q6UPD14Y6>U!!
M4E]414U0?2`]("(D14Y6>U!!4E]414U0?2)=*3L*;7D@*"1S=&%R=%]P;W,L
M("1D871A7W!O<RD["DU!1TE#.B!["FQO8V%L("1324=[7U]705).7U]](#T@
M<W5B('M].PIU;FQE<W,@*&]P96X@7T9(+"`G/#IR87<G+"`D<')O9VYA;64I
M('L*;W5T<RAQ<5M#86XG="!R96%D(&9R;VT@9FEL92`B)'!R;V=N86UE(ETI
M.R`@(R!D;VXG="!U<V4@)"$@:&5R92!A<R!I="!R97%U:7)E<R!%<G)N;RYP
M;0IL87-T($U!1TE#.PI]"FUY("1M86=I8U]P;W,@/2!F:6YD7W!A<E]M86=I
M8R@J7T9(*3L*:68@*"1M86=I8U]P;W,@/"`P*2!["F]U=',H<7%;0V%N)W0@
M9FEN9"!M86=I8R!S=')I;F<@(B1005)?34%'24,B(&EN(&9I;&4@(B1P<F]G
M;F%M92)=*3L*;&%S="!-04=)0SL*?0IO=71S*")&;W5N9"!005(@;6%G:6,@
M870@<&]S:71I;VX@)&UA9VEC7W!O<R(I.PIS965K(%]&2"P@)&UA9VEC7W!O
M<R`M("1&24Q%7V]F9G-E=%]S:7IE+"`P.PIR96%D(%]&2"P@)&)U9BP@)$9)
M3$5?;V9F<V5T7W-I>F4["FUY("1O9F9S970@/2!U;G!A8VLH(DXB+"`D8G5F
M*3L*;W5T<R@B3V9F<V5T(&9R;VT@<W1A<G0@;V8@1DE,17,@:7,@)&]F9G-E
M="(I.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M("1&24Q%7V]F9G-E=%]S:7IE
M("T@)&]F9G-E="P@,#L*)&1A=&%?<&]S(#T@=&5L;"!?1D@["FUY("5R97%U
M:7)E7VQI<W0["G)E860@7T9(+"`D8G5F+"`T.R`@("`@("`@("`@("`@("`@
M("`@("`@("`@(",@<F5A9"!T:&4@9FER<W0@(D9)3$4B"G=H:6QE("@D8G5F
M(&5Q(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B
M=68L('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO
M=71S*'%Q6U5N<&%C:VEN9R!&24Q%("(D9G5L;&YA;64B+BXN72D["FUY("1C
M<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q
M(#H@=6YD968["FUY("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH
M/SHN*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L(#0["G)E860@
M7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN960H)&5X
M="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F
M:6QE;F%M92`](%]S879E7V%S*"(D8W)C)&5X="(L("1B=68L(#`W-34I.PHD
M4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64[
M"B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M
M93L*?0IE;'-I9B`H("1F=6QL;F%M92`]?B!M?%XO/W-H;&EB+WP@86YD(&1E
M9FEN960@)$5.5GM005)?5$5-4'T@*2!["FUY("1F:6QE;F%M92`](%]S879E
M7V%S*"(D8F%S96YA;64D97AT(BP@)&)U9BP@,#<U-2D["F]U=',H(E-(3$E"
M.B`D9FEL96YA;65<;B(I.PI]"F5L<V4@>PHD36]D=6QE0V%C:&5[)&9U;&QN
M86UE?2`]('L*8G5F(#T^("1B=68L"F-R8R`]/B`D8W)C+`IN86UE(#T^("1F
M=6QL;F%M92P*?3L*)')E<75I<F5?;&ES='LD9G5L;&YA;65]*RL["GT*<F5A
M9"!?1D@L("1B=68L(#0["GT*;&]C86P@0$E.0R`]("AS=6(@>PIM>2`H)'-E
M;&8L("1M;V1U;&4I(#T@0%\["G)E='5R;B!I9B!R968@)&UO9'5L92!O<B`A
M)&UO9'5L93L*;7D@)&EN9F\@/2`D36]D=6QE0V%C:&5[)&UO9'5L97T["G)E
M='5R;B!U;FQE<W,@)&EN9F\["F1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U
M;&5].PHD24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O)&EN9F\O)&UO9'5L92([
M"FEF("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN
M97<I*2!["FUY("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D:64@
M(D-A;B=T(&-R96%T92!T96UP(&9I;&4Z("0A(CL*)&9H+3YB:6YM;V1E*"D[
M"B1F:"T^<')I;G0H)&EN9F\M/GMB=69]*3L*)&9H+3YS965K*#`L(#`I.PIR
M971U<FX@)&9H.PI]"F5L<V4@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B
M)&EN9F\M/GMC<F-]+G!M(BP@)&EN9F\M/GMB=69]*3L*)&EN9F\M/GMF:6QE
M?2`]("1F:6QE;F%M93L*;W!E;B!M>2`D9F@L("<\.G)A=R<L("1F:6QE;F%M
M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)&9I;&5N86UE(CH@)"%=.PIR971U
M<FX@)&9H.PI]"F1I92`B0F]O='-T<F%P<&EN9R!F86EL960Z(&-A;B=T(&9I
M;F0@;6]D=6QE("1M;V1U;&4A(CL*?2P@0$E.0RD["G)E<75I<F4@6%-,;V%D
M97(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!#87)P.CI(96%V>3L*
M<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y
M;F%L;V%D97(H*3L*<F5Q=6ER92!)3SHZ1FEL93L*=VAI;&4@*&UY("1F:6QE
M;F%M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L*=6YL97-S
M("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2![
M"FEF("@D9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PIR97%U:7)E("1F:6QE
M;F%M93L*?0IE;'-E('L*9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@
M/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\["GT*?0ID96QE=&4@)')E<75I<F5?
M;&ES='LD9FEL96YA;65].PI]"G5N;&5S<R`H)&)U9B!E<2`B4$M<,#`S7#`P
M-"(I('L*;W5T<RAQ<5M.;R!Z:7`@9F]U;F0@869T97(@1DE,12!S96-T:6]N
M(&EN(&9I;&4@(B1P<F]G;F%M92)=*3L*;&%S="!-04=)0R`["GT*)'-T87)T
M7W!O<R`]("AT96QL(%]&2"D@+2`T.R`@("`@("`@("`@("`@("`C('-T87)T
M(&]F('II<`I]"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L
M;V=F:"P@)&-A8VAE7VYA;64I.PID96QE=&4@)$5.5GM005)?05!07U)%55-%
M?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE
M;2D*:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP72!E<2`G+2UP87(M;W!T
M:6]N<R<@)B8@<VAI9G0I*2!["FUY("5D:7-T7V-M9"`]('%W*`IP("`@8FQI
M8E]T;U]P87(*:2`@(&EN<W1A;&Q?<&%R"G4@("!U;FEN<W1A;&Q?<&%R"G,@
M("!S:6=N7W!A<@IV("`@=F5R:69Y7W!A<@HI.PII9B`H0$%21U8@86YD("1!
M4D=66S!=(&5Q("<M+7)E=7-E)RD@>PIS:&EF="!`05)'5CL*)$5.5GM005)?
M05!07U)%55-%?2`]('-H:69T($!!4D=6.PI]"F5L<V4@>R`C(&YO<FUA;"!P
M87)L(&)E:&%V:6]U<@IM>2!`861D7W1O7VEN8SL*=VAI;&4@*$!!4D=6*2![
M"B1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA
M<W0["FEF("@D,2!E<2`G22<I('L*<'5S:"!`861D7W1O7VEN8RP@)#(["GT*
M96QS:68@*"0Q(&5Q("=-)RD@>PIE=F%L(")U<V4@)#(B.PI]"F5L<VEF("@D
M,2!E<2`G02<I('L*=6YS:&EF="!`<&%R7V%R9W,L("0R.PI]"F5L<VEF("@D
M,2!E<2`G3R<I('L*)&]U="`]("0R.PI]"F5L<VEF("@D,2!E<2`G8B<I('L*
M)&)U;F1L92`]("=S:71E)SL*?0IE;'-I9B`H)#$@97$@)T(G*2!["B1B=6YD
M;&4@/2`G86QL)SL*?0IE;'-I9B`H)#$@97$@)W$G*2!["B1Q=6EE="`](#$[
M"GT*96QS:68@*"0Q(&5Q("=,)RD@>PIO<&5N("1L;V=F:"P@(CX^(BP@)#(@
M;W(@9&EE('%Q6T-A;B=T(&]P96X@;&]G(&9I;&4@(B0R(CH@)"%=.PI]"F5L
M<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D,CL*?0IS:&EF="A`
M05)'5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PID96QE=&4@
M)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q=6ER92!005(Z.D1I
M<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6.PHF>R)0
M05(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE>&ET.PI]"GT*=6YS
M:&EF="!`24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF("@D;W5T*2!["GL*<F5Q
M=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@
M1&EG97-T.CI32$$["GT*;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*;7D@)'II
M<#L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@
M)'!A<B!O<B!D:64@<7%;0V%N)W0@9FEN9"!P87(@9FEL92`B)'!A<B(Z("0A
M73L*8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII
M<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I
M(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92!Q<5M%<G)O<B!R
M96%D:6YG('II<"!A<F-H:79E("(D<&%R(ET["GT*;7D@)6UE=&%?<&%R(#T@
M9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G
M345402YY;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@
M/7X@<R]>7%,N*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M
M9SL*?0I].PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)'!H+"`G/#IR
M87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!R96%D('!A<B!F:6QE("(D<&%R
M(CH@)"%=.PIM>2`D8G5F.PIR96%D("1P:"P@)&)U9BP@-#L*9&EE('%Q6R(D
M<&%R(B!I<R!N;W0@82!P87(@9FEL95T@=6YL97-S("1B=68@97$@(E!+7#`P
M,UPP,#0B.PIC;&]S92`D<&@["GT*0W)E871E4&%T:"@D;W5T*2`["FUY("1F
M:"`]($E/.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/7T-214%4*"D@
M?"!)3SHZ1FEL93HZ3U]74D].3%DH*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL
M"C`W-S<L"BD@;W(@9&EE('%Q6T-A;B=T(&-R96%T92!F:6QE("(D;W5T(CH@
M)"%=.PHD9F@M/F)I;FUO9&4H*3L*<V5E:R!?1D@L(#`L(#`["FUY("1L;V%D
M97(["FEF("AD969I;F5D("1D871A7W!O<RD@>PIR96%D(%]&2"P@)&QO861E
M<BP@)&1A=&%?<&]S.PI](&5L<V4@>PIL;V-A;"`D+R`]('5N9&5F.PHD;&]A
M9&5R(#T@/%]&2#X["GT*:68@*"$D14Y6>U!!4E]615)"051)37T@86YD("1L
M;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E<75I<F4@4$%2.CI&:6QT
M97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD
M;&]A9&5R+"`D,"D["GT*:68@*"1M971A7W!A<GMC;&5A;GTI('L*;7D@)'!A
M<E]C;&5A;B`]("(],2(["FUY("1P87-S7W!A<E]C;&5A;B`]('5C(")?7W!A
M<W-?<&%R7V-L96%N7U\B.PHD;&]A9&5R(#U^('-[*#\\/21[<&%S<U]P87)?
M8VQE86Y]*2@@*RE]"GLD<&%R7V-L96%N("X@*"(@(B!X("AL96YG=&@H)#$I
M("T@;&5N9W1H*"1P87)?8VQE86XI*2E]96<["GT*)&9H+3YP<FEN="@D;&]A
M9&5R*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!L;V%D97(@=&\@(B1O=70B
M.B`D(5T["FEF("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*4$%2
M.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR97%U
M:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R97`@>R`A+T)31%!!3B\@?0IG
M<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I9SHZ
M0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF:6=[
M<')I=FQI8F5X<'TI.PI]($!)3D,["G-\+RM\+WQG+"!S?"\D?'P@9F]R96%C
M:"!`:6YC.PIM>2`E9FEL97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y;F%,;V%D
M97(Z.F1L7W-H87)E9%]O8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@)&QI8E]E
M>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T[("`@("`@("`@(R!86%@@
M;&EB7V5X="!V<R!D;&5X="`_"FUY("5W<FET=&5N.PIF;W)E86-H(&UY("1K
M97D@*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@*"1F:6QE+"`D;F%M92D["FEF
M("AD969I;F5D*&UY("1F8R`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&ME
M>7TI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("1F8RD["GT*96QS92![
M"F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H)&ME>2`]?B!M?%Y<421D
M:7)<12\H+BHI)'QI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("0Q*3L*
M;&%S=#L*?0II9B`H)&ME>2`]?B!M?%XO;&]A9&5R+UM>+UTK+R@N*BDD?"D@
M>PII9B`H;7D@)')E9B`]("1-;V1U;&5#86-H97LD,7TI('L**"1F:6QE+"`D
M;F%M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]"FEF("@M9B`B)&1I<B\D,2(I
M('L**"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*
M?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M93L*;F5X="!I9B`D=W)I
M='1E;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@
M/7X@+UPN7%$D;&EB7V5X=%Q%)"]I.PIO=71S*'-P<FEN=&8H<7%;4&%C:VEN
M9R!&24Q%("(E<R(N+BY=+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@
M)&9I;&4I*3L*;7D@)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2!["B1C;VYT
M96YT(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@>PIL;V-A;"`D+R`]('5N9&5F
M.PIO<&5N(&UY("1T:"P@)SPZ<F%W)RP@)&9I;&4@;W(@9&EE('%Q6T-A;B=T
M(')E860@(B1F:6QE(CH@)"%=.PHD8V]N=&5N="`](#PD=&@^.PIC;&]S92`D
M=&@["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1C;VYT96YT+"`B
M/&5M8F5D9&5D/B\D;F%M92(I"FEF("$D14Y6>U!!4E]615)"051)37T@86YD
M("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A
M=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M
M92D["GT*)&9H+3YP<FEN="@B1DE,12(L"G!A8VLH)TXG+"!L96YG=&@H)&YA
M;64I("L@.2DL"G-P<FEN=&8H(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O
M;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE*2P*<&%C:R@G3B<L(&QE;F=T
M:"@D8V]N=&5N="DI+`HD8V]N=&5N="D*;W(@9&EE('%Q6T5R<F]R('=R:71I
M;F<@96UB961D960@1DE,12!T;R`B)&]U="(Z("0A73L*;W5T<RAQ<5M7<FET
M=&5N(&%S("(D;F%M92)=*3L*?0I]"FEF("@D>FEP*2!["B1Z:7`M/G=R:71E
M5&]&:6QE2&%N9&QE*"1F:"D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2PIO<B!D
M:64@<7%;17)R;W(@=W)I=&EN9R!Z:7`@<&%R="!O9B`B)&]U=")=.PI]"B1C
M86-H95]N86UE(#T@<W5B<W1R("1C86-H95]N86UE+"`P+"`D8V%C:&5?;F%M
M95]S:7IE.PII9B`H(21C86-H95]N86UE(&%N9"!M>2`D;71I;64@/2`H<W1A
M="@D;W5T*2E;.5TI('L*;7D@)&-T>"`]($1I9V5S=#HZ4TA!+3YN97<H,2D[
M"F]P96X@;7D@)'1H+"`B/#IR87<B+"`D;W5T.PHD8W1X+3YA9&1F:6QE*"1T
M:"D["F-L;W-E("1T:#L*)&-A8VAE7VYA;64@/2`D8W1X+3YH97AD:6=E<W0[
M"GT*)&-A8VAE7VYA;64@+CT@(EPP(B!X("@D8V%C:&5?;F%M95]S:7IE("T@
M;&5N9W1H("1C86-H95]N86UE*3L*)&-A8VAE7VYA;64@+CT@)&-A8VAE7VUA
M<FME<CL*;7D@)&]F9G-E="`]("1F:"T^=&5L;"`K(&QE;F=T:"@D8V%C:&5?
M;F%M92D@+2!L96YG=&@H)&QO861E<BD["B1F:"T^<')I;G0H)&-A8VAE7VYA
M;64L"G!A8VLH)TXG+"`D;V9F<V5T*2P*)%!!4E]-04=)0RD*)B8@)&9H+3YC
M;&]S90IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!T<F%I;&5R(&]F("(D;W5T
M(CH@)"%=.PIC:&UO9"`P-S4U+"`D;W5T.PIE>&ET.PI]"GL*;&%S="!U;FQE
M<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PI?9FEX7W!R;V=N86UE*"D["G)E<75I
M<F4@4$%2.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["GL*<F5Q
M=6ER92!&:6QE.CI&:6YD.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM>2`D
M9F@@/2!)3SHZ1FEL92T^;F5W.R`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(R!!<F-H:79E.CI::7`@;W!E<F%T97,@;VX@86X@24\Z.DAA;F1L90HD
M9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@<7%;9F1O<&5N
M*"D@9F%I;&5D.B`D(5T["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*"US
M(%]&2"D["FUY("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL**"1Z:7`M/G)E
M861&<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C:&EV93HZ
M6FEP.CI!6E]/2R@I*0IO<B!D:64@<7%;17)R;W(@<F5A9&EN9R!Z:7`@87)C
M:&EV92`B)'!R;V=N86UE(ET["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE
M*#8T("H@,3`R-"D["G!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B1005(Z
M.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PIO=71S*")%>'1R86-T:6YG
M('II<"XN+B(I.PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@>R`C('-H
M;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*9F]R96%C:"!M>2`D;65M8F5R
M("@@)'II<"T^;65M8F5R<R`I('L*;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C
M=&]R>3L*;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA;64["FYE
M>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M>PI>"B\_<VAL:6(O"B@_.B1#
M;VYF:6<Z.D-O;F9I9WMV97)S:6]N?2\I/PHH/SHD0V]N9FEG.CI#;VYF:6=[
M87)C:&YA;65]+RD_"BA;7B]=*RD*)`I]>#L*;7D@)&5X=')A8W1?;F%M92`]
M("0Q.PIM>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D14Y6
M>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D["FEF("@M9B`D9&5S=%]N86UE
M("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2!["F]U
M=',H<7%;4VMI<'!I;F<@(B1M96UB97)?;F%M92(@<VEN8V4@:70@86QR96%D
M>2!E>&ES=',@870@(B1D97-T7VYA;64B72D["GT@96QS92!["F]U=',H<7%;
M17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M92(N+BY=
M*3L**"1M96UB97(M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*2`]
M/2!!<F-H:79E.CI::7`Z.D%:7T]+*"DI"F]R(&1I92!Q<5M%<G)O<B!E>'1R
M86-T:6YG('II<"!M96UB97(@=&\@(B1D97-T7VYA;64B73L*8VAM;V0H,#4U
M-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*?0I]"GT*?0IU;FQE
M<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*9&EE(#P\("(N(B!U
M;FQE<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@
M72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*)#`@
M6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@HD14Y6>U!!4E]04D]'
M3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6*3L*?0IS=6(@
M0W)E871E4&%T:"!["FUY("@D;F%M92D@/2!`7SL*<F5Q=6ER92!&:6QE.CI"
M87-E;F%M93L*;7D@*"1B87-E;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ
M0F%S96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI.PIR97%U:7)E
M($9I;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S
M*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*<W5B(')E
M<75I<F5?;6]D=6QE<R!["G)E<75I<F4@;&EB.PIR97%U:7)E($1Y;F%,;V%D
M97(["G)E<75I<F4@:6YT96=E<CL*<F5Q=6ER92!S=')I8W0["G)E<75I<F4@
M=V%R;FEN9W,["G)E<75I<F4@=F%R<SL*<F5Q=6ER92!#87)P.PIR97%U:7)E
M($-A<G`Z.DAE879Y.PIR97%U:7)E($5R<FYO.PIR97%U:7)E($5X<&]R=&5R
M.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CL*<F5Q=6ER92!&8VYT;#L*<F5Q
M=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.E-P96,["G)E<75I<F4@
M6%-,;V%D97(["G)E<75I<F4@0V]N9FEG.PIR97%U:7)E($E/.CI(86YD;&4[
M"G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@0V]M<')E<W,Z.EIL:6(["G)E
M<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S=#HZ4TA!.PIR97%U
M:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E(%!!4CHZ1&ES
M=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E<75I<F4@4$%2
M.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R:6)U=&5S.PIE
M=F%L('L@<F5Q=6ER92!#=V0@?3L*979A;"![(')E<75I<F4@5VEN,S(@?3L*
M979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["F5V86P@>R!R97%U:7)E
M($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q=6ER92!4:64Z
M.DAA<V@Z.DYA;65D0V%P='5R92!].PIE=F%L('L@<F5Q=6ER92!097)L24\[
M(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*979A;"![(')E<75I<F4@=71F
M."!].PI]"G-U8B!?<V5T7W!A<E]T96UP('L*:68@*&1E9FEN960@)$5.5GM0
M05)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PHD<&%R
M7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@)'!A=&@@*`HH;6%P
M("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0
M(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@>PIN97AT('5N;&5S
M<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["FUY
M("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W=6ED*2`](&=E='!W
M=6ED*"0^*2!I9B!D969I;F5D("0^.WT["FEF("@@9&5F:6YE9"@F5VEN,S(Z
M.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE
M.PI]"F5L<VEF("AD969I;F5D("1P=W5I9"D@>PHD=7-E<FYA;64@/2`D<'=U
M:60["GT*96QS92!["B1U<V5R;F%M92`]("1%3E9[55-%4DY!345]('Q\("1%
M3E9[55-%4GT@?'P@)U-94U1%32<["GT*;7D@)'-T;7!D:7(@/2`B)'!A=&@D
M<WES>U]D96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD
M:7(@)'-T;7!D:7(L(#`W-34["FUY("1C86-H95]D:7(["FEF("@D14Y6>U!!
M4E]#3$5!3GTI('L*)&-A8VAE7V1I<B`](")T96UP+20D(CL*?0IE;'-E('L*
M;W!E;B!M>2`D9F@L("(\.G)A=R(L("1P<F]G;F%M92!O<B!D:64@<7%;0V%N
M)W0@<F5A9"`B)'!R;V=N86UE(CH@)"%=.PII9B`H*&UY("1M86=I8U]P;W,@
M/2!F:6YD7W!A<E]M86=I8R@D9F@I*2`^/2`P*2!["G-E96L@)&9H+"`D;6%G
M:6-?<&]S"BT@)$9)3$5?;V9F<V5T7W-I>F4*+2!L96YG=&@H)&-A8VAE7VUA
M<FME<BDL(#`["FUY("1B=68["G)E860@)&9H+"`D8G5F+"!L96YG=&@H)&-A
M8VAE7VUA<FME<BD["FEF("@D8G5F(&5Q("1C86-H95]M87)K97(I('L*<V5E
M:R`D9F@L("1M86=I8U]P;W,*+2`D1DE,15]O9F9S971?<VEZ90HM(&QE;F=T
M:"@D8V%C:&5?;6%R:V5R*0HM("1C86-H95]N86UE7W-I>F4L(#`["G)E860@
M)&9H+"`D8G5F+"`D8V%C:&5?;F%M95]S:7IE.PHD8G5F(#U^(',O7#`O+V<[
M"B1C86-H95]D:7(@/2`B8V%C:&4M)&)U9B(["GT*?0IC;&]S92`D9F@["GT*
M:68@*"$D8V%C:&5?9&ER*2!["B1C86-H95]D:7(@/2`B=&5M<"TD)"(["B1%
M3E9[4$%27T-,14%.?2`](#$["GT*)'-T;7!D:7(@+CT@(B1S>7-[7V1E;&EM
M?21C86-H95]D:7(B.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*)$5.5GM005)?
M5$5-4'T@/2`D<W1M<&1I<CL*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D
M14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]
M"G-U8B!?<V%V95]A<R!["FUY("@D;F%M92P@)&-O;G1E;G1S+"`D;6]D92D@
M/2!`7SL*;7D@)&9U;&QN86UE(#T@(B1P87)?=&5M<"\D;F%M92(["G5N;&5S
M<R`H+64@)&9U;&QN86UE*2!["FUY("1T96UP;F%M92`]("(D9G5L;&YA;64N
M)"0B.PIM>2`D9F@["BAO<&5N("1F:"P@)SXZ<F%W)RP@)'1E;7!N86UE*0HF
M)B`H<')I;G0@)&9H("1C;VYT96YT<RD*)B8@*&-L;W-E("1F:"D*;W(@9&EE
M('%Q6T5R<F]R('=R:71I;F<@(B1T96UP;F%M92(Z("0A73L*8VAM;V0@)&UO
M9&4L("1T96UP;F%M92!I9B!D969I;F5D("1M;V1E.PIR96YA;64H)'1E;7!N
M86UE+"`D9G5L;&YA;64I(&]R('5N;&EN:R@D=&5M<&YA;64I.PI]"G)E='5R
M;B`D9G5L;&YA;64["GT*<W5B(%]S971?<')O9VYA;64@>PII9B`H9&5F:6YE
M9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%27U!23T=.04U%?2`]
M?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@)#$["GT*)'!R;V=N86UE('Q\/2`D
M,#L*:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%
M3E9[4$%27U1%35!]*2`^/2`P*2!["B1P<F]G;F%M92`]('-U8G-T<B@D<')O
M9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@*R`Q*3L*
M?0II9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E>"@D<')O9VYA;64L
M("1S>7-[7V1E;&EM?2D@/CT@,"D@>PII9B`H;W!E;B!M>2`D9F@L("<\)RP@
M)'!R;V=N86UE*2!["G)E='5R;B!I9B`M<R`D9F@["GT*:68@*"US("(D<')O
M9VYA;64D<WES>U]E>&5](BD@>PHD<')O9VYA;64@+CT@)'-Y<WM?97AE?3L*
M<F5T=7)N.PI]"GT*9F]R96%C:"!M>2`D9&ER("AS<&QI="`O7%$D<WES>W!A
M=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6
M>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]
M?B!S+UQ1)'-Y<WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D
M<WES>U]D96QI;7TD<')O9VYA;64D<WES>U]E>&5](BDL(&QA<W0I"FEF("US
M("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE)'-Y<WM?97AE?2(["B@H)'!R
M;V=N86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D*
M:68@+7,@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B.PI]"GT*<W5B(%]F
M:7A?<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?4%)/
M1TY!345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI(#P@
M,"D@>PHD<')O9VYA;64@/2`B+B1S>7-[7V1E;&EM?21P<F]G;F%M92(["GT*
M;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W
M9"@I"CH@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#
M=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P<F]G;F%M92`]?B!S+UXH
M/SU<+EPN/UQ1)'-Y<WM?9&5L:6U]7$4I+R1P=V0D<WES>U]D96QI;7TO.PHD
M14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*<W5B(%]P87)?:6YI
M=%]E;G8@>PII9B`H("1%3E9[4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2![
M"G)E='5R;CL*?2!E;'-E('L*)$5.5GM005)?24Y)5$E!3$E:141](#T@,CL*
M?0IF;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/
M1TY!344@*2`I('L*9&5L971E("1%3E9[(E!!4E\D7R)].PI]"F9O<B`H<7<O
M(%1-4$1)4B!414U0($-,14%.($1%0E5'("\I('L*)$5.5GLB4$%27R1?(GT@
M/2`D14Y6>R)005)?1TQ/0D%,7R1?(GT@:68@97AI<W1S("1%3E9[(E!!4E]'
M3$]"04Q?)%\B?3L*?0II9B`H)$5.5GM005)?5$5-4'TI('L*9&5L971E("1%
M3E9[4$%27T-,14%.?3L*?0I]"G-U8B!O=71S('L*<F5T=7)N(&EF("1Q=6EE
M=#L*:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB.PI]"F5L<V4@
M>PIP<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR97%U:7)E($-O
M;F9I9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#
M;VYF:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H
M97AP('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E>'`**3L*
M?0IP86-K86=E(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF
M4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*9&EE('%Q
M6W!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@
M3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN70IU;FQE<W,@+64@)'!R;V=N
M86UE.PID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>
M7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*?3L*)#HZ7U]%
M4E)/4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T52
M4D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@
M:68@)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH`<&5R;'AS:2YC````/0```$``
M```+````0````!````!`````)@```$`````U````0`````,```!`````!@``
M`$`````4````0`````X```!`````#0```$`````E````0````!(```!`````
M*````$`````"````0````!@```!`````"0```$`````*````0```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````(T5```U%0``
M`0```",#```!````+@,```\```!Z!```#`````40```-````13```!D```#,
M_0$`&P````0````:````T/T!`!P````$````]?[_;RP!```%````I`@```8`
M```4`@``"@```)@$```+````$````!4``````````P```,3^`0`"````X`$`
M`!0````1````%P```"0.```1````/`T``!(```#H````$P````@````8````
M`````/O__V\!```(^O__;Q``````````````````````````````````````
M````````````````````U/T!````````````#!````P0```,$```#!````P0
M```,$```#!````P0```,$```#!````P0```,$```#!````P0```,$```#!``
M``P0```,$```#!````P0```,$```#!````P0```,$```#!````P0```,$```
M#!````P0```,$```#!````P0```,$```#!````P0```,$```#!````P0```,
M$```#!````P0```,$```#!````P0```,$```#!````P0```,$```#!````P0
M```,$```#!````P0```,$```#!````P0```,$```#!````P0```,$```_1(`
M````````````13``````````````!1``````````````````````````````
M`````````````````````````@#_____@C,``-TP````````OC$``+<Q``!V
M,P``U#$``'XS````````:#,``&TS````````AS,``$=#0SH@*$%L<&EN92`Q
M,BXR+C%?9VET,C`R,C`Y,C0M<C0I(#$R+C(N,2`R,#(R,#DR-`!!,@```&%E
M86)I``$H````!3<M00`&"@=!"`$)`@H$$@03`10!%0$7`Q@!&@(<`1X$(@$`
M+G-H<W1R=&%B`"YI;G1E<G``+F=N=2YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N
M<F5L+F1Y;@`N<F5L+G!L=``N:6YI=``N=&5X=``N9FEN:0`N<F]D871A`"YE
M:%]F<F%M90`N:6YI=%]A<G)A>0`N9FEN:5]A<G)A>0`N9'EN86UI8P`N9V]T
M`"YD871A`"YB<W,`+F-O;6UE;G0`+D%232YA='1R:6)U=&5S````````````
M```````````````````````````````````````````+`````0````(````4
M`0``%`$``!@```````````````$`````````$P```/;__V\"````+`$``"P!
M``#H`````P`````````$````!````!T````+`````@```!0"```4`@``D`8`
M``0````#````!````!`````E`````P````(```"D"```I`@``)@$````````
M``````$`````````+0````D````"````/`T``#P-``#H`````P`````````$
M````"````#8````)````0@```"0.```D#@``X`$```,````0````!`````@`
M```_`````0````8````$$```!!````@```````````````(`````````.@``
M``$````&````#!````P0``#P`@`````````````$````!````$4````!````
M!@```/P2``#\$@``2!T`````````````!`````````!+`````0````8```!$
M,```1#````@```````````````(`````````40````$````"````3#```$PP
M``#,00`````````````$`````````%D````!`````@```!AR```8<@``!```
M````````````!`````````!C````#@````,```#,_0$`S/T```0`````````
M``````0````$````;P````\````#````T/T!`-#]```$```````````````$
M````!````'L````&`````P```-3]`0#4_0``\`````0`````````!`````@`
M``"$`````0````,```#$_@$`Q/X``#P!``````````````0````$````B0``
M``$````#```````"`````0`\```````````````$`````````(\````(````
M`P```#P``@`\``$`+```````````````!`````````"4`````0```#``````
M````/``!`#0```````````````$````!````G0````,``'```````````'``
M`0`S```````````````!``````````$````#``````````````"C``$`K0``
1`````````````0``````````
